relative_tags = {
    "PX": "Phường xã",
    "QH": "Quận huyện",
    "TTP": "Tỉnh thành phố"
}

exactly_tags = {
    "P": "phường",
    "X": "xã",
    "TT": "thị trấn",
    "Q": "quận",
    "H": "huyện",
    "TX": "thị xã",
    "T": "tỉnh",
    "TP": "thành phố"
}

FULL_TAG_LIST = ['PX', 'QH', 'TTP']

tag_order = {
    "PX": 1,
    "QH": 2,
    "TTP": 3
}
